@@ -234,7 +234,83 @@ my %abbrev = (
   'Revelation' => [ qw(re rev apoc apocalypse) ],
 );
 
-sub _books { { chapters => \%chapters, abbrev => \%abbrev } }
+my %short_form = (
+  'Genesis'   => 'Gen',
+  'Exodus'    => 'Ex',
+  'Leviticus' => 'Lev',
+  'Numbers'   => 'Num',
+  'Deuteronomy' => 'Deut',
+  'Joshua'    => 'Josh',
+  'Judges'    => 'Judg',
+  'Ruth'      => 'Ruth',
+  '1 Samuel'  => '1 Sam',
+  '2 Samuel'  => '2 Sam',
+  '1 Kings'   => '1 Ki',
+  '2 Kings'   => '2 Ki',
+  '1 Chronicles' => '1 Chr',
+  '2 Chronicles' => '2 Chr',
+  'Ezra'      => 'Ezra',
+  'Nehemiah'  => 'Neh',
+  'Esther'    => 'Esth',
+  'Job'       => 'Job',
+  'Psalms'    => 'Ps',
+  'Proverbs'  => 'Prov',
+  'Ecclesiastes' => 'Ecc',
+  'Song of Solomon' => 'Song',
+  'Isaiah'    => 'Is',
+  'Jeremiah'  => 'Jer',
+  'Lamentations' => 'Lam',
+  'Ezekiel'   => 'Ezek',
+  'Daniel'    => 'Dan',
+  'Hosea'     => 'Hos',
+  'Joel'      => 'Joel',
+  'Amos'      => 'Amos',
+  'Obadiah'   => 'Obad',
+  'Jonah'     => 'Jon',
+  'Micah'     => 'Micah',
+  'Nahum'     => 'Nahum',
+  'Habakkuk'  => 'Hab',
+  'Zephaniah' => 'Zeph',
+  'Haggai'    => 'Hag',
+  'Zechariah' => 'Zec',
+  'Malachi'   => 'Mal',
+  # New Testament
+  'Matthew'   => 'Mt',
+  'Mark'      => 'Mk',
+  'Luke'      => 'Lk',
+  'John'      => 'Jn',
+  'Acts'      => 'Acts',
+  'Romans'    => 'Rom',
+  '1 Corinthians' => '1 Cor',
+  '2 Corinthians' => '2 Cor',
+  'Galatians' => 'Gal',
+  'Ephesians' => 'Eph',
+  'Philippians' => 'Phi',
+  'Colossians'  => 'Col',
+  '1 Thessalonians' => '1 Th',
+  '2 Thessalonians' => '2 Th',
+  '1 Timothy' => '1 Tim',
+  '2 Timothy' => '2 Tim',
+  'Titus'     => 'Tit',
+  'Philemon'  => 'Phm',
+  'Hebrews'   => 'Heb',
+  'James'     => 'Jas',
+  '1 Peter'   => '1 Pe',
+  '2 Peter'   => '2 Pe',
+  '1 John'    => '1 Jn',
+  '2 John'    => '2 Jn',
+  '3 John'    => '3 Jn',
+  'Jude'      => 'Jude',
+  'Revelation' => 'Rev',
+);
+
+sub _books {
+  return {
+    chapters   => \%chapters,
+    abbrev     => \%abbrev,
+    short_form => \%short_form,
+  }
+}
 
 =head1 AUTHOR
 
